@@ -115,7 +115,7 @@ class LoadResponse(object):
     def to_dict(self):
         """Generate a dict representation."""
 
-        return self.incremental_data._asdict()
+        return dict(self.incremental_data._asdict())
 
     @property
     def incremental_data_names(self):
@@ -269,9 +269,9 @@ class LoadResponseSet(object):
         self.responses = load_responses
 
         # All appended to in given methods, or in self.from_dict:
-        self.yield_point_criteria = []  # `self.calculate_yield_stresses`
-        self.yield_stresses = []        # `self.calculate_yield_stresses`
-        self.yield_functions = []       # `self.calculate_yield_function_fit`
+        self.yield_point_criteria = []      # `self.calculate_yield_stresses`
+        self.yield_stresses = []            # `self.calculate_yield_stresses`
+        self.fitted_yield_functions = []    # `self.calculate_yield_function_fit`
 
     def __repr__(self):
         inc_data = []
@@ -293,8 +293,8 @@ class LoadResponseSet(object):
         out = {
             'responses': [i.to_dict() for i in self.responses],
             'yield_point_criteria': [i.to_dict() for i in self.yield_point_criteria],
-            'yield_stresses': self.yield_stresses,
-            'yield_functions': [
+            'yield_stresses': [dict(i._asdict()) for i in self.yield_stresses],
+            'fitted_yield_functions': [
                 {
                     'YPC_idx': i['YPC_idx'],
                     'YPC_value_idx': i['YPC_value_idx'],
@@ -302,9 +302,10 @@ class LoadResponseSet(object):
                     'yield_function': {
                         'name': i['yield_function'].name,
                         **i['yield_function'].get_parameters(),
+                        'fit_info': dict(i['yield_function'].fit_info),
                     }
                 }
-                for i in self.yield_functions
+                for i in self.fitted_yield_functions
             ],
         }
         return out
@@ -313,7 +314,7 @@ class LoadResponseSet(object):
     def from_dict(cls, dct):
         """Reconstitute a LoadResponseSet object from a dict."""
 
-        obj = cls(load_responses=dct['responses'])
+        obj = cls(load_responses=copy.deepcopy(dct['responses']))
 
         # Reconstitute a pre-existing `LoadResponseSet`:
         if 'yield_stresses' in dct:
@@ -333,8 +334,8 @@ class LoadResponseSet(object):
                         ypc = YieldPointCriteria(**ypc)
                     obj.yield_point_criteria.append(ypc)
 
-            if dct.get('yield_functions'):
-                for yld_func in dct['yield_functions']:
+            if dct.get('fitted_yield_functions'):
+                for yld_func in dct['fitted_yield_functions']:
                     if not isinstance(yld_func['yield_function'], YieldFunction):
                         yld_func_obj = YieldFunction.from_name(
                             **yld_func['yield_function']
@@ -345,7 +346,7 @@ class LoadResponseSet(object):
                             'yield_stress_idx': yld_func['yield_stress_idx'],
                             'yield_function': yld_func_obj,
                         }
-                    obj.yield_functions.append(yld_func_dict)
+                    obj.fitted_yield_functions.append(yld_func_dict)
 
         return obj
 
@@ -410,14 +411,14 @@ class LoadResponseSet(object):
     def _validate_yield_function_parameters(self, yield_function,
                                             yield_point_criteria_idx,
                                             yield_point_criteria_value_idx,
-                                            uniaxial_response, **kwargs):
+                                            uniaxial_response, **fixed_params):
 
         ypc = self.yield_point_criteria[yield_point_criteria_idx]
 
         uniaxial_eq_stress = None
         if 'equivalent_stress' in yield_function.PARAMETERS:
 
-            if 'equivalent_stress' not in kwargs:
+            if 'equivalent_stress' not in fixed_params:
 
                 if uniaxial_response is not None:
                     # equivalent stress is calculated as the yield stress in the
@@ -447,20 +448,21 @@ class LoadResponseSet(object):
                    'an equivalent stress parameter, so `{}` is not required.')
             if uniaxial_response is not None:
                 raise ValueError(msg.format('uniaxial_response'))
-            if kwargs.get('equivalent_stress') is not None:
+            if fixed_params.get('equivalent_stress') is not None:
                 raise ValueError(msg.format('equivalent_stress'))
 
-        kwargs_copy = copy.deepcopy(kwargs)
+        fixed_params_copy = copy.deepcopy(fixed_params)
         if uniaxial_eq_stress:
-            kwargs_copy.update({
+            fixed_params_copy.update({
                 'equivalent_stress': uniaxial_eq_stress,
             })
 
-        return kwargs_copy
+        return fixed_params_copy
 
     @at_most_one_of('equivalent_stress', 'uniaxial_response')
     def fit_yield_function(self, yield_function, yield_point_criteria_idx=None,
-                           uniaxial_response=None, initial_params=None, **kwargs):
+                           uniaxial_response=None, initial_params=None, opt_params=None,
+                           **fixed_params):
         """Perform a fit to a yield function of all computed yield stresses.
 
         Parameters
@@ -476,7 +478,17 @@ class LoadResponseSet(object):
         initial_params : dict, optional
             Any initial guesses for the fitting parameters. Mutually exclusive with
             additional keyword arguments passed, which are considered to be fixed.
-        kwargs : dict
+        opt_params : dict, optional
+            Optimisation parameters. Dict with any of the keys:
+                default_bounds : list of length two, optional
+                    The bounds applied to all non-fixed yield function parameters by
+                    default.
+                bounds : dict, optional
+                    Dict of bounds for individual named parameters. These bounds take
+                    precedence over `default_bounds`.
+                **kwargs : dict
+                    Other parameters to be passed to the SciPy least_squares function.
+        **fixed_params : dict
             Any yield function parameters to be fixed during the fit can be passed as
             additional keyword arguments.
 
@@ -496,7 +508,7 @@ class LoadResponseSet(object):
         elif not issubclass(yield_function, YieldFunction):
             raise TypeError(msg)
 
-        bad_kwargs = list(set(kwargs.keys()) - set(yield_function.PARAMETERS))
+        bad_kwargs = list(set(fixed_params.keys()) - set(yield_function.PARAMETERS))
         if bad_kwargs:
             bad_kwargs_fmt = ', '.join([f'"{i}"' for i in bad_kwargs])
             raise ValueError(f'Unknown yield function parameters: {bad_kwargs_fmt}')
@@ -534,13 +546,14 @@ class LoadResponseSet(object):
                 ypc_idx,
                 ypc_val_idx,
                 uniaxial_response,
-                **kwargs
+                **fixed_params
             )
 
             # Perform fit:
             yld_func_obj = yield_function.from_fit(
                 yield_stress,
                 initial_params=initial_params,
+                opt_params=opt_params,
                 **updated_kwargs
             )
 
@@ -548,12 +561,12 @@ class LoadResponseSet(object):
             yld_func_obj.yield_point = ypc.get_formatted(values_idx=ypc_val_idx)
             yield_func_dict['yield_function'] = yld_func_obj
 
-            self.yield_functions.append(yield_func_dict)
+            self.fitted_yield_functions.append(yield_func_dict)
 
     def remove_yield_function_fits(self):
         'Remove all yield function fits'
 
-        self.yield_functions = []
+        self.fitted_yield_functions = []
 
     def show_yield_functions_3D(self, normalise=True, resolution=DEF_3D_RES,
                                 equivalent_stress=None, min_stress=None, max_stress=None,
@@ -562,17 +575,17 @@ class LoadResponseSet(object):
                                 show_contour_grid=False, layout=None,):
         'Visualise all fitted yield functions and data in 3D.'
 
-        if not self.yield_functions:
+        if not self.fitted_yield_functions:
             raise ValueError('No yield functions have been fitted to the load set.')
 
         yld_funcs = []
         yld_stresses = []
         stress_indices = []
-        for yld_func_dict in self.yield_functions:
+        for yld_func_dict in self.fitted_yield_functions:
             yld_funcs.append(yld_func_dict['yield_function'])
             yld_stress = self.yield_stresses[yld_func_dict['yield_stress_idx']]
-            yld_stress_vals = yld_stress['values']
-            resp_idx = yld_stress['response_idx']
+            yld_stress_vals = yld_stress.values
+            resp_idx = yld_stress.response_idx
             yld_stress_principal = get_principal_values(yld_stress_vals)
             yld_stresses.append(yld_stress_principal)
             stress_indices.append(resp_idx)
@@ -606,17 +619,17 @@ class LoadResponseSet(object):
                                 show_numerical_lankford_fit=False, layout=None):
         'Visualise all fitted yield functions and data in 2D.'
 
-        if not self.yield_functions:
+        if not self.fitted_yield_functions:
             raise ValueError('No yield functions have been fitted to the load set.')
 
         yld_funcs = []
         yld_stresses = []
         stress_indices = []
-        for yld_func_dict in self.yield_functions:
+        for yld_func_dict in self.fitted_yield_functions:
             yld_funcs.append(yld_func_dict['yield_function'])
             yld_stress = self.yield_stresses[yld_func_dict['yield_stress_idx']]
-            yld_stress_vals = yld_stress['values']
-            resp_idx = yld_stress['response_idx']
+            yld_stress_vals = yld_stress.values
+            resp_idx = yld_stress.response_idx
             yld_stress_principal = get_principal_values(yld_stress_vals)
             yld_stresses.append(yld_stress_principal)
             stress_indices.append(resp_idx)
