@@ -6,12 +6,13 @@ inherit from this class.
 """
 
 import abc
+import copy
 import functools
 
 import numpy as np
 from plotly import graph_objects
 from plotly.colors import DEFAULT_PLOTLY_COLORS
-from scipy.optimize import least_squares, curve_fit
+from scipy.optimize import least_squares, curve_fit, OptimizeResult
 
 from formable import utils, maths_utils
 from formable.yielding.map import get_yield_function_map
@@ -89,7 +90,7 @@ class YieldFunction(metaclass=abc.ABCMeta):
         return value
 
     @classmethod
-    def from_name(cls, name, **parameters):
+    def from_name(cls, name, fit_info=None, **parameters):
         'Get a specific yield function from the name and parameters.'
         YIELD_FUNCTION_MAP = get_yield_function_map()
         if name not in YIELD_FUNCTION_MAP:
@@ -98,11 +99,18 @@ class YieldFunction(metaclass=abc.ABCMeta):
                    f'are: {available}.')
             raise ValueError(msg)
 
+        if fit_info:
+            fit_info = OptimizeResult(**fit_info)
+
         yld_func_class = YIELD_FUNCTION_MAP[name]
-        return yld_func_class(**parameters)
+        yld_func = yld_func_class(**parameters)
+        yld_func.fit_info = fit_info
+
+        return yld_func
 
     @classmethod
-    def from_fit(cls, stress_states, initial_params=None, force_fit=False, **kwargs):
+    def from_fit(cls, stress_states, initial_params=None, force_fit=False,
+                 opt_params=None, **fixed_params):
         """Fit the yield function to yield stress states.
 
         Parameters
@@ -110,39 +118,58 @@ class YieldFunction(metaclass=abc.ABCMeta):
         stress_states : ndarray of shape (N, 3, 3)
         initial_params : dict
             Any initial guesses for the fitting parameters. Mutually exclusive with
-            additional keyword arguments passed, which are considered to be fixed.
+            additional keyword arguments (**fixed_params) passed, which are considered
+            to be fixed.
         force_fit : bool, optional
             If False, do not fit if there is insufficient input data. False by default.
-        kwargs : dict
+        opt_params : dict, optional
+            Optimisation parameters. Dict with any of the keys:
+                default_bounds : list of length two, optional
+                    The bounds applied to all non-fixed yield function parameters by
+                    default.
+                bounds : dict, optional
+                    Dict of bounds for individual named parameters. These bounds take
+                    precedence over `default_bounds`.
+                **kwargs : dict
+                    Other parameters to be passed to the SciPy least_squares function.
+
+        **fixed_params : dict
             Additional parameters passed to this method will be fixed during the fit.
 
         Returns
         -------
         yield_function : YieldFunction
-            The fitted yield function.
+            The fitted yield function, with a populated `fit_info` attribute if a fit
+            was performed.
 
         """
 
-        fitting_param_names = [i for i in cls.PARAMETERS if i not in kwargs]
+        fitting_param_names = [i for i in cls.PARAMETERS if i not in fixed_params]
         initial_params_all = np.ones(len(fitting_param_names))
 
         initial_params = initial_params or {}
 
-        if initial_params:
-            for k, initial_guess in initial_params.items():
-                if k not in fitting_param_names:
-                    msg = (f'Initial guess specified for parameter "{k}", but this '
-                           'parameter has also been specified as a keyword argument, '
-                           'indicating it should be fixed.')
+        for param_name, initial_guess in initial_params.items():
+            if param_name not in fitting_param_names:
+                if param_name not in cls.PARAMETERS:
+                    msg = (f'Initial guess specified for parameter "{param_name}", but '
+                           f'this parameter does not exist for the specified yield '
+                           f'function, "{cls.__name__}".')
                     raise ValueError(msg)
-                param_idx = fitting_param_names.index(k)
-                initial_params_all[param_idx] = initial_guess
+                elif param_name in fixed_params:
+                    msg = (f'Initial guess specified for parameter "{param_name}", but '
+                           f'this parameter has also been specified as a keyword '
+                           f'argument, indicating it should be fixed.')
+                    raise ValueError(msg)
+
+            param_idx = fitting_param_names.index(param_name)
+            initial_params_all[param_idx] = initial_guess
 
         if not fitting_param_names:
 
             # Construct yield function, but no need to fit:
-            yield_function = cls(**kwargs)
-            fit = None
+            yield_function = cls(**fixed_params)
+            fit_info = None
 
         else:
 
@@ -159,21 +186,59 @@ class YieldFunction(metaclass=abc.ABCMeta):
                 idx = fitting_param_names.index('equivalent_stress')
                 initial_params_all[idx] = 50e6
 
-            fit = least_squares(
+            bounds_all = (-np.inf, +np.inf)
+            if opt_params:
+                opt_params = copy.deepcopy(opt_params)
+                def_bounds = opt_params.pop('default_bounds', None)
+                bounds_dict = opt_params.pop('bounds', None)
+
+                if def_bounds:
+                    bounds_all = [
+                        [def_bounds[0]] * len(initial_params_all),
+                        [def_bounds[1]] * len(initial_params_all),
+                    ]
+                else:
+                    bounds_all = [
+                        [-np.inf] * len(initial_params_all),
+                        [+np.inf] * len(initial_params_all),
+                    ]
+
+                if bounds_dict:
+                    for param_name, param_bounds in bounds_dict.items():
+
+                        if param_name not in cls.PARAMETERS:
+                            msg = (f'Fitting bounds specified for parameter '
+                                   f'"{param_name}", but this parameter does not exist '
+                                   f'for the specified yield function, "{cls.__name__}".')
+                            raise ValueError(msg)
+                        elif param_name in fixed_params:
+                            msg = (f'Fitting bounds specified for parameter '
+                                   f'"{param_name}", but this parameter has also been '
+                                   f'specified as a keyword argument, indicating it '
+                                   f'should be fixed.')
+                            raise ValueError(msg)
+
+                        param_idx = fitting_param_names.index(param_name)
+                        bounds_all[0][param_idx] = param_bounds[0]
+                        bounds_all[1][param_idx] = param_bounds[1]
+
+            fit_info = least_squares(
                 cls.residual,
                 initial_params_all,
+                bounds=tuple(bounds_all),
                 kwargs=dict(
                     stress_states=stress_states,
                     fitting_param_names=fitting_param_names,
-                    **kwargs,
-                )
+                    **fixed_params,
+                ),
+                **(opt_params or {}),
             )
 
-            parameters = dict(zip(fitting_param_names, fit.x))
-            parameters.update(**kwargs)
+            parameters = dict(zip(fitting_param_names, fit_info.x))
+            parameters.update(**fixed_params)
             yield_function = cls(**parameters)
 
-        yield_function.fit = fit
+        yield_function.fit_info = fit_info
 
         return yield_function
 
